import { ChangeDetectorRef, ElementRef, EventEmitter, OnInit, Renderer2 } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * Component that wraps the native HTML5 color picker for supported browsers
 */
export declare class ColorPickerComponent implements ControlValueAccessor, OnInit {
    private renderer;
    private changeDetectorRef;
    /**
     * Regex to match a hexadecimal string (000000)
     * @private
     */
    private static readonly FULL_HEX_REGEX;
    /**
     * Regex to match a short hexadecimal string (000)
     * @private
     */
    private static readonly SHORT_HEX_REGEX;
    /**
     * Regex to match a valid hex character (A-F, a-f, 0-9)
     * @private
     */
    private static readonly HEX_CHARACTER_REGEX;
    /**
     * Navigation keys
     * @private
     */
    private static readonly NAVIGATION_KEYS;
    /**
     * Set the value of the color picker
     * @param value the value to set
     */
    set value(value: string);
    /**
     * Set disabled
     * @param disabled whether or not the control should be disabled
     */
    set disabled(disabled: boolean);
    /**
     * Aria label input
     */
    ariaLabel: string;
    /**
     * Class list to apply to the hex string input
     */
    classList: string;
    /**
     * Event emitted on hex string input event. Emits the current value of the input
     */
    input: EventEmitter<string>;
    /**
     * Event emitted on color selection from color picker (color picker widget dismissed)
     * or valid hex string typed in input. Emits the current value of the input
     */
    colorSelected: EventEmitter<string>;
    /**
     * ViewChild of the color input element
     */
    colorInput: ElementRef<HTMLInputElement>;
    /**
     * Whether or not to render the component
     */
    render: boolean;
    /**
     * Whether or not the native HTML5 color picker is supported
     */
    colorPickerSupported: boolean;
    /**
     * The value of the color picker
     */
    _value: string;
    /**
     * Whether or not the color picker is disabled
     * @private
     */
    _disabled: boolean;
    /**
     * Expand a short hex string (#abc) into its full form (#aabbcc)
     * @param hexString the short hex string to expand
     * @private
     */
    private static expandShortHexString;
    /**
     * Function to call on change
     */
    onChange: (value: any) => void;
    /**
     * Function to call on touch
     */
    onTouched: () => any;
    /**
     * Dependency injection site
     * @param renderer the Angular renderer
     * @param changeDetectorRef the Angular ChangeDetectorRef
     */
    constructor(renderer: Renderer2, changeDetectorRef: ChangeDetectorRef);
    /**
     * Init component, check for color picker browser support
     */
    ngOnInit(): void;
    /**
     * Write value
     * @param value the value to write
     */
    writeValue(value: string): void;
    /**
     * Register on change function
     * @param fn the function to register
     */
    registerOnChange(fn: any): void;
    /**
     * Register on touched function
     * @param fn the function to register
     */
    registerOnTouched(fn: any): void;
    /**
     * Set whether or not the control should be disabled
     * @param isDisabled disabled or not
     */
    setDisabledState(isDisabled: boolean): void;
    /**
     * Prevent illegal input
     * @param event the keydown KeyboardEvent
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Update model
     * @param value the new value of the model
     * @param emitColorSelected whether or not emit the color selected event
     * @private
     */
    updateModel(value: string, emitColorSelected?: boolean): void;
    /**
     * Null out value on blur if not valid hex string, otherwise update model
     * @param value the value to check
     */
    handleBlur(value: string): void;
    /**
     * Prevent pasting a non-hex string
     * @param event the paste ClipboardEvent
     */
    handlePaste(event: ClipboardEvent): void;
    /**
     * Determine if the browser supports the HTML5 color picker
     * @private
     */
    private isColorPickerSupported;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColorPickerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColorPickerComponent, "wily-color-picker", never, { "value": "value"; "disabled": "disabled"; "ariaLabel": "ariaLabel"; "classList": "classList"; }, { "input": "input"; "colorSelected": "colorSelected"; }, never, never>;
}
