import { ElementRef, EventEmitter, OnDestroy, OnInit, QueryList, Renderer2 } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * Interface representing a date interval
 */
export declare interface Interval {
    start: Date | number;
    end: Date | number;
}
/**
 * Interface representing a Date broken down by date/month/year
 * with extended metadata
 */
declare interface MetaDate {
    /**
     * The day of the week (starting at 0)
     */
    day: number;
    /**
     * The day of the month (starting at 1)
     */
    date: number;
    /**
     * The month (starting at 0)
     */
    month: number;
    /**
     * The full year
     */
    year: number;
    /**
     * Whether or not the day is selectable
     */
    selectable: boolean;
}
/**
 * Component that allows a user to select a date from a calendar
 */
export declare class CalendarComponent implements OnDestroy, OnInit {
    private renderer;
    /**
     * The keyboard arrow keys
     * @private
     */
    private static readonly ARROW_KEYS;
    /**
     * ViewChild of the calendar widget parent div element
     */
    calendarWidgetDiv: ElementRef<HTMLDivElement>;
    /**
     * ViewChild of the month select element
     */
    yearSelect: ElementRef<HTMLSelectElement>;
    /**
     * ViewChild of the done button
     */
    doneButton: ElementRef<HTMLButtonElement>;
    /**
     * QueryList of the calendar date buttons for the currently selected month/year
     */
    calendarDates: QueryList<ElementRef<HTMLButtonElement>>;
    /**
     * The selected date value
     */
    set value(value: Date);
    /**
     * The range of available dates to choose from
     */
    set dateRange(dateRange: {
        minDate: Date;
        maxDate: Date;
    });
    /**
     * Event emitted on date select
     */
    selected: EventEmitter<Date>;
    /**
     * Event emitted on close (either through the button, escape keyup or click off of widget).
     * Note: it is the parent component's job to actually hide the calendar, this event
     *       acts as a signal that that action should be taken
     */
    closed: EventEmitter<void>;
    /**
     * The current Date broken down by day/month/year
     */
    readonly currentDate: MetaDate;
    /**
     * Array of days of the week
     */
    readonly weekDays: string[];
    /**
     * BehaviorSubject tracking the current value
     */
    readonly _value: BehaviorSubject<MetaDate>;
    /**
     * BehaviorSubject tracking the valid selection interval
     */
    readonly _validSelectionInterval: BehaviorSubject<Interval>;
    /**
     * BehaviorSubject tracking the currently selected month
     */
    readonly _selectedMonth: BehaviorSubject<number>;
    /**
     * BehaviorSubject tracking the currently selected year
     */
    readonly _selectedYear: BehaviorSubject<number>;
    /**
     * The full month for the current selected month/year
     */
    readonly fullMonth$: Observable<Array<MetaDate>>;
    /**
     * The range of selectable years as an Observable
     */
    readonly validYearRange$: Observable<Array<number>>;
    /**
     * Subscription for the combination of value and valid selection interval
     * @private
     */
    private readonly subscription;
    /**
     * The currently selected date
     */
    selectedDate: MetaDate;
    /**
     * Generate a 42 element array representing the input month's days with
     * padding from the previous/following month
     * @param month the month to generate dates for
     * @param year the year to generate the month for
     * @param selectionInterval the selection interval
     */
    private static generateMonth;
    /**
     * Generate an Array of numbers representing the span of years between the input
     * @param minYear the start of the range
     * @param maxYear the end of the range
     * @param currentYear the current year
     */
    private static generateYearRange;
    /**
     * Dependency injection site
     * @param renderer the Angular renderer
     */
    constructor(renderer: Renderer2);
    /**
     * Init component
     */
    ngOnInit(): void;
    /**
     * Destroy component, unsubscribe from any active subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Handle window keyup events
     * @param event the keyup KeyboardEvent
     */
    onKeyUp(event: KeyboardEvent): void;
    /**
     * Emit closed event on click if clicked outside calendar widget
     * @param event the click MouseEvent
     */
    handleClick(event: MouseEvent): void;
    /**
     * Update selected date and emit selection event
     * @param selectedDate the selected date
     */
    handleDateSelection(selectedDate: MetaDate): void;
    /**
     * Select the current date and toggle selected month/year to match
     */
    selectToday(): void;
    /**
     * Handle arrow key navigation for calendar date buttons
     * @param key the pressed arrow key
     * @private
     */
    private onArrowKeyUp;
    /**
     * Attempt to focus on date indexed immediately to the left of the input date
     * @param date the day of the month
     * @private
     */
    private navigateLeft;
    /**
     * Attempt to focus on date indexed immediately to the right of the input date
     * @param date the day of the month
     * @private
     */
    private navigateRight;
    /**
     * Attempt to navigate one week in the past from the input date
     * @param date the day of the month
     * @private
     */
    private navigateUp;
    /**
     * Attempt to navigate one week in the future from the input date
     * @param date the day of the month
     * @private
     */
    private navigateDown;
    static ɵfac: i0.ɵɵFactoryDeclaration<CalendarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CalendarComponent, "wily-calendar", never, { "value": "value"; "dateRange": "dateRange"; }, { "selected": "selected"; "closed": "closed"; }, never, never>;
}
export {};
