import { AnimationEvent } from '@angular/animations';
import { ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit, Renderer2 } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * Component to allow a user to input/select a date
 */
export declare class DatePickerComponent implements ControlValueAccessor, OnDestroy, OnInit {
    private renderer;
    private changeDetectorRef;
    /**
     * Allowed keys for date input
     */
    private static readonly ALLOWED_KEYS;
    /**
     * Matches MM/DD/YYYY
     * @private
     */
    private static readonly FULL_DATE_FORMAT;
    /**
     * Matches M/D/YYYY
     * @private
     */
    private static readonly SHORT_DATE_FORMAT;
    /**
     * Matches M/DD/YYYY
     * @private
     */
    private static readonly SHORT_MONTH_DATE_FORMAT;
    /**
     * Matches MM/D/YYYY
     * @private
     */
    private static readonly SHORT_DAY_DATE_FORMAT;
    /**
     * A reference date with all fields set to 0
     * @private
     */
    private static readonly referenceDate;
    /**
     * Value input setter
     */
    set value(value: Date);
    set disabled(disabled: boolean);
    set dateRange(dateRange: {
        minDate: Date;
        maxDate: Date;
    });
    /**
     * The ID to set on the input
     */
    inputId: string;
    /**
     * Value to use as the date picker input's aria label
     */
    ariaLabel: string;
    /**
     * Optional class-list to add to the date picker input
     */
    inputClassList: string;
    /**
     * Optional class-list to add to the calendar button
     */
    calendarButtonClassList: string;
    /**
     * Event emitted on date picker input
     */
    input: EventEmitter<void>;
    /**
     * Event emitted on valid date selection/input
     */
    dateSelected: EventEmitter<Date>;
    /**
     * ViewChild of the date picker div
     */
    datePickerDiv: ElementRef<HTMLDivElement>;
    /**
     * ViewChild of the calendar div
     */
    calendarDiv: ElementRef<HTMLDivElement>;
    /**
     * The current date
     */
    private readonly currentDate;
    /**
     * The fixed height of the calendar widget
     */
    private readonly calendarHeight;
    /**
     * The fixed width of the calendar widget
     */
    private readonly calendarWidth;
    /**
     * The amount of padding to apply between the date picker input and the calendar widget
     */
    private readonly calendarPadding;
    /**
     * String tracking date picker input
     */
    dateString: string;
    /**
     * Whether or not the calendar should be rendered
     */
    render: boolean;
    /**
     * Whether or not to show the calendar
     */
    showCalendar: {
        currentValue: Date;
    };
    /**
     * The valid selection interval
     * @private
     */
    validSelectionInterval: {
        start: Date;
        end: Date;
    };
    /**
     * The internal control accessor value
     * @private
     */
    private _value;
    /**
     * The internal disabled state
     * @private
     */
    private _disabled;
    /**
     * Window resize unlisten function
     */
    private resizeListener;
    /**
     * Parse the input Date value into a string
     * @param value the value to parse
     * @private
     */
    private static parseDate;
    /**
     * Parse the input date string into a Date
     * @param dateString the string to parse
     * @private
     */
    private static parseDateString;
    /**
     * Get the date format that matches the input date string, null if no match
     * @param dateString the string to test
     * @private
     */
    private static getDateFormat;
    /**
     * Function to call on change
     */
    onChange: (value: any) => void;
    /**
     * Function to call on touch
     */
    onTouched: () => any;
    /**
     * Dependency injection site
     * @param renderer the Angular renderer
     * @param changeDetectorRef the Angular change detector
     */
    constructor(renderer: Renderer2, changeDetectorRef: ChangeDetectorRef);
    /**
     * Value getter
     */
    get value(): Date;
    /**
     * Disabled getter
     */
    get disabled(): boolean;
    /**
     * Init component, set up window resize listener
     */
    ngOnInit(): void;
    /**
     * Destroy component, invoke window resize unlisten function
     */
    ngOnDestroy(): void;
    /**
     * Write value
     * @param value the value to write
     */
    writeValue(value: Date): void;
    /**
     * Register control value accessor change function
     * @param fn the function to register
     */
    registerOnChange(fn: (value: any) => void): void;
    /**
     * Register touch handler
     * @param fn the touch handler to register
     */
    registerOnTouched(fn: any): void;
    /**
     * Set the disabled state
     * @param isDisabled whether or not the component should be disabled
     */
    setDisabledState?(isDisabled: boolean): void;
    /**
     * Only allow input from digits, forward slashes, and navigation keys
     */
    filterInput(event: KeyboardEvent): void;
    /**
     * Clear value if no input, write parsed date if input requirements fulfilled
     */
    handleBlur(): void;
    /**
     * Write on input if valid date within interval
     */
    handleInput(): void;
    /**
     * Update the model value
     * @param value the value to update the model to
     */
    updateModel(value: Date): void;
    /**
     * Set calendar position on animation start if toState is open
     * @param event the Angular AnimationEvent
     */
    onAnimationStart(event: AnimationEvent): void;
    /**
     * Flip render to false on animation done if toState is close
     * @param event the Angular AnimationEvent
     */
    onAnimationDone(event: AnimationEvent): void;
    /**
     * Open the calendar widget
     * @param event the click MouseEvent
     */
    openCalendar(event: MouseEvent): void;
    /**
     * Hide calendar overlay and remove calendar from the DOM
     */
    handleCalendarClose(): void;
    /**
     * Calculate and set the calendar's position based on the screen height.
     * Positioning prefers to open at the bottom, if not enough room on bottom,
     * positioning is attempted at the top, otherwise it attempts to vertically
     * center
     */
    private setCalendarPosition;
    static ɵfac: i0.ɵɵFactoryDeclaration<DatePickerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DatePickerComponent, "wily-date-picker", never, { "value": "value"; "disabled": "disabled"; "dateRange": "dateRange"; "inputId": "inputId"; "ariaLabel": "ariaLabel"; "inputClassList": "inputClassList"; "calendarButtonClassList": "calendarButtonClassList"; }, { "input": "input"; "dateSelected": "dateSelected"; }, never, never>;
}
