import { AnimationEvent } from '@angular/animations';
import { ChangeDetectorRef, ElementRef, EventEmitter, QueryList, Renderer2, TemplateRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { BehaviorSubject, Observable } from 'rxjs';
import { DropdownOption } from './models/dropdown-option.model';
import { DropdownOptionGroup } from './models/dropdown-option-group.model';
import * as i0 from "@angular/core";
/**
 * Type representing the dropdown component option input
 */
declare type DropdownOptionInput = Array<DropdownOption | DropdownOptionGroup>;
/**
 * Dropdown component
 */
export declare class DropdownComponent implements ControlValueAccessor {
    private renderer;
    private changeDetectorRef;
    /**
     * Set the value of the dropdown
     * @param value the value to set
     */
    set value(value: string | number);
    get value(): string | number;
    /**
     * The dropdown options/option groups
     */
    set options(options: DropdownOptionInput);
    /**
     * Dependency injection site
     * @param renderer the Angular renderer
     * @param changeDetectorRef reference to the Angular change detector
     */
    constructor(renderer: Renderer2, changeDetectorRef: ChangeDetectorRef);
    /**
     * The amount of offset (in pixels) to place between the dropdown
     * and its list overlay
     * @private
     */
    private static readonly DROPDOWN_LIST_OFFSET;
    /**
     * List of arrow key keycodes
     * @private
     */
    private static readonly ARROW_KEYS;
    /**
     * ViewChild of the dropdown
     */
    dropdown: ElementRef<HTMLDivElement>;
    /**
     * ViewChild of the dropdown button
     */
    dropdownButton: ElementRef<HTMLButtonElement>;
    /**
     * ViewChild of the dropdown list
     */
    dropdownList: ElementRef<HTMLDivElement>;
    /**
     * QueryList of dropdown option ViewChildren
     */
    dropdownOptions: QueryList<ElementRef<HTMLButtonElement>>;
    /**
     * ContentChild of the dropdown option template
     */
    template: TemplateRef<HTMLElement>;
    /**
     * Whether or not the dropdown should be disabled
     */
    disabled: boolean;
    /**
     * Placeholder text to display when no option is selected
     */
    placeholder: string;
    /**
     * Aria label text
     */
    ariaLabel: string;
    /**
     * Class list to assign to the dropdown
     */
    classList: string;
    /**
     * Event emitted on value change, emits the new value
     */
    change: EventEmitter<string | number>;
    /**
     * BehaviorSubject tracking the input dropdown options/option groups
     */
    readonly _options: BehaviorSubject<DropdownOptionInput>;
    /**
     * BehaviorSubject tracking the current value of the dropdown
     */
    readonly _internalValue: BehaviorSubject<string | number>;
    /**
     * Observable map of option value (stringified if a number) to data context
     */
    private readonly dataContextMap$;
    /**
     * The data context of the selected option as an Observable
     */
    readonly selectedDataContext$: Observable<{
        [key: string]: unknown;
    }>;
    /**
     * Unique ID to assign to the dropdown
     */
    readonly dropdownId: any;
    /**
     * Whether or not the dropdown should be rendered
     */
    render: boolean;
    /**
     * Whether or not the dropdown is open
     */
    opened: boolean;
    /**
     * The index of the focused option in the dropdown list
     */
    selectionIndex: number;
    /**
     * The current value of the dropdown
     * @private
     */
    private _value;
    /**
     * Removes options that do not have both a label and a value,
     * also removes empty groups (or groups that have no valid options)
     * @param options the options to sanitize
     * @private
     */
    private static sanitizeOptionInput;
    /**
     * Add option label to data context if not present. If $implicit
     * value is not present, it will be added with the label as its value.
     * If $implicit is already present, it will add a label key to the context
     * @param label the option label
     * @param dataContext the option data context
     * @private
     */
    private static addLabelToDataContext;
    /**
     * Function to call on change
     */
    onChange: (value: any) => void;
    /**
     * Function to call on touch
     */
    onTouched: () => any;
    /**
     * Write value
     * @param value the value to write
     */
    writeValue(value: string | number): void;
    /**
     * Register function on change
     * @param fn the function to register
     */
    registerOnChange(fn: any): void;
    /**
     * Register function on touch
     * @param fn the function to register
     */
    registerOnTouched(fn: any): void;
    /**
     * Set the disabled state
     * @param isDisabled disabled or not
     */
    setDisabledState?(isDisabled: boolean): void;
    /**
     * Reposition and resize the dropdown on window resize
     */
    onWindowResize(): void;
    /**
     * Prevent default behavior for arrow key keydown event
     * @param event the keydown KeyboardEvent
     */
    onKeyDown(event: KeyboardEvent): void;
    /**
     * Close the dropdown list on tab and handle arrow key navigation
     * @param event the keyup KeyboardEvent
     */
    onKeyUp(event: KeyboardEvent): void;
    /**
     * Close the dropdown list (if opened) on click if outside the list
     * @param event the click MouseEvent
     */
    onClick(event: MouseEvent): void;
    /**
     * Close dropdown on escape keyup and focus on dropdown button
     * @param event the keyup KeyboardEvent
     */
    onEscapeKeyUp(event: Event): void;
    /**
     * Set focus to dropdown option on mouse enter and update selected index
     * @param option the dropdown option to focus
     * @param index the index of the option to focus
     */
    onDropdownOptionMouseEnter(option: HTMLButtonElement, index: number): void;
    /**
     * Set focus to dropdown option on mouse move and update selected index
     * @param option the dropdown option to focus
     * @param index the index of the option to focus
     */
    onDropdownOptionMouseMove(option: HTMLButtonElement, index: number): void;
    /**
     * Write value and close dropdown on option select
     * @param value the value to write
     * @param disabled whether or not the selected option is disabled
     */
    onDropdownOptionSelect(value: string | number, disabled: boolean): void;
    /**
     * Open the dropdown list and align it
     * @param event the click MouseEvent
     */
    openDropdown(event: MouseEvent): void;
    /**
     * Close the dropdown list
     */
    closeDropdown(): void;
    /**
     * Position and resize dropdown list on animation start if toState is open
     * @param event the Angular AnimationEvent
     */
    onAnimationStart(event: AnimationEvent): void;
    /**
     * Stop rendering dropdown list on animation done if toState is close
     * @param event the Angular AnimationEvent
     */
    onAnimationDone(event: AnimationEvent): void;
    /**
     * Focus on the selected dropdown option on dropdown open
     * @private
     */
    setSelectionIndex(): void;
    /**
     * Update internal value and emit change events if input value differs from current value
     * @param value the selected value
     * @private
     */
    private handleDropdownOptionSelect;
    /**
     * Align the dropdown list with the dropdown
     * @private
     */
    private positionDropdownList;
    /**
     * Match the dropdown list width to the dropdown's width
     * @private
     */
    private resizeDropdownList;
    /**
     * Handle arrow keyup event
     * @param key the arrow key
     */
    private onArrowKeyUp;
    /**
     * Get the next enabled dropdown option (relative to the current selection index).
     * If the currently selected option is the final available option, it is
     * returned. If no selection has been made, the first available option is returned
     * @private
     */
    private getNextOption;
    /**
     * Get the previous enabled dropdown option (relative to the current selection index).
     * If the currently selected option is the first available option, it is
     * returned
     * @private
     */
    private getPreviousOption;
    static ɵfac: i0.ɵɵFactoryDeclaration<DropdownComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DropdownComponent, "wily-dropdown", never, { "value": "value"; "options": "options"; "disabled": "disabled"; "placeholder": "placeholder"; "ariaLabel": "ariaLabel"; "classList": "classList"; }, { "change": "change"; }, ["template"], ["template"]>;
}
export {};
