import { ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { IconsService } from '../services/icons.service';
import * as i0 from "@angular/core";
/**
 * Wily Icon Select component provides a button to click and an icon picker that includes all of the Wily Icons as well as the FAS icons.
 */
export declare class IconSelectComponent implements ControlValueAccessor, OnDestroy {
    private service;
    private changeDetectorRef;
    /**
     * The number of items to display per page
     * @private
     */
    private static readonly PAGE_SIZE;
    /**
     * Set the value of the icon select
     * @param value the value to set
     */
    set value(value: string);
    /**
     * Set disabled
     * @param disabled whether or not the icon picker should be disabled
     */
    set disabled(disabled: boolean);
    /**
     * Color class of the button
     */
    buttonColorClass: string;
    /**
     * The value to set to the button's width, min-width, height and min-height
     */
    buttonSizing: string;
    /**
     * Icon select opened event emitter
     */
    opened: EventEmitter<void>;
    /**
     * Icon selected event emitter
     */
    selected: EventEmitter<any>;
    /**
     * Dialog closed event emitter
     */
    closed: EventEmitter<any>;
    /**
     * The scrollable icon container
     */
    iconScrollContainer: ElementRef<HTMLDivElement>;
    /**
     * BehaviorSubject tracking the input value destructed into its prefix and class name
     */
    readonly _internalValue: BehaviorSubject<{
        prefix: string;
        name: string;
    }>;
    /**
     * BehaviorSubject tracking the current filter value selection for icons
     */
    readonly _filter: BehaviorSubject<{
        style: 'all' | 'solid' | 'regular' | 'light' | 'brands';
        type: 'all' | 'wily' | 'fontawesome';
    }>;
    /**
     * BehaviorSubject tracking the current icon search text value
     */
    readonly _searchText: BehaviorSubject<string>;
    /**
     * BehaviorSubject that emits when search button has been clicked
     */
    readonly _searchClick: BehaviorSubject<string>;
    /**
     * BehaviorSubject tracking the active pagination page
     */
    readonly _activePage: BehaviorSubject<number>;
    /**
     * Subject that emits on search input enter keyup
     */
    readonly _searchInputEnterKeyup: Subject<void>;
    /**
     * An array of all icons (as strings) that meet the current filter/search criteria as an Observable
     * @private
     */
    private readonly icons$;
    /**
     * The count of total paginator pages as an Observable
     */
    readonly totalPages$: Observable<number>;
    /**
     * Observable boolean indicating whether or not the user can perform an icon text search
     */
    readonly canSearch$: Observable<boolean>;
    /**
     * Observable boolean indicating whether or not the user can paginate to the previous page
     */
    readonly canPaginatePrevious$: Observable<boolean>;
    /**
     * Observable boolean indicating whether or not the user can paginate to the next page
     */
    readonly canPaginateNext$: Observable<boolean>;
    /**
     * Paginated icons array as an Observable
     */
    readonly paginatedIcons$: Observable<Array<{
        prefix: string;
        name: string;
    }>>;
    /**
     * Object that controls whether to show the dialog or not
     */
    showDialog: any;
    /**
     * Whether or not to show the icon selection preview
     */
    showIconSelectionPreview: boolean;
    /**
     * Subscription object to store search input enter keyup subscription
     * @private
     */
    private readonly subscription;
    /**
     * The value of the icon select
     * @private
     */
    private _value;
    /**
     * Whether or not the icon picker is disabled
     * @private
     */
    private _disabled;
    /**
     * Function to call on change
     */
    onChange: (value: any) => void;
    /**
     * Function to call on touch
     */
    onTouched: () => any;
    /**
     * Dependency injection site
     * @param service the IconsService
     * @param changeDetectorRef the Angular ChangeDetectorRef
     */
    constructor(service: IconsService, changeDetectorRef: ChangeDetectorRef);
    /**
     * Get disabled
     */
    get disabled(): boolean;
    /**
     * Destroy component, unsubscribe from search input enter keyup subscription
     */
    ngOnDestroy(): void;
    /**
     * Write the input value
     * @param value the value to write
     */
    writeValue(value: string): void;
    /**
     * Register onChange function
     * @param fn the function to register
     */
    registerOnChange(fn: any): void;
    /**
     * Register onTouched function
     * @param fn the function to register
     */
    registerOnTouched(fn: any): void;
    /**
     * Set disabled state
     * @param isDisabled whether or not the icon picker should be disabled
     */
    setDisabledState(isDisabled: boolean): void;
    /**
     * Open the icon select dialog
     */
    openDialog(): void;
    /**
     * Close the icon select dialog
     */
    closeDialog(): void;
    /**
     * Handle filter select
     * @param filter the selected filter
     */
    handleFilterSelect(filter: {
        style: 'all' | 'solid' | 'regular' | 'light' | 'brands';
        type: 'all' | 'wily' | 'fontawesome';
    }): void;
    /**
     * Update internal value on icon select
     * @param icon the selected icon
     */
    handleIconSelect(icon: {
        prefix: string;
        name: string;
    }): void;
    /**
     * Write value on confirm
     */
    handleIconSelectConfirm(): void;
    /**
     * Go to the next pagination page
     */
    paginateNext(): void;
    /**
     * Go to the previous pagination page
     */
    paginatePrevious(): void;
    /**
     * Clear search text and reset paginator
     */
    clearSearch(): void;
    /**
     * Update model
     * @param value the new value of the model
     * @private
     */
    private updateModel;
    /**
     * Reset filtering/pagination BehaviorSubject values
     * @private
     */
    private reset;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconSelectComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IconSelectComponent, "wily-icon-select", never, { "value": "value"; "disabled": "disabled"; "buttonColorClass": "buttonColorClass"; "buttonSizing": "buttonSizing"; }, { "opened": "opened"; "selected": "selected"; "closed": "closed"; }, never, never>;
}
