import { AnimationEvent } from '@angular/animations';
import { ChangeDetectorRef, ElementRef, EventEmitter, QueryList, Renderer2, TemplateRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { BehaviorSubject, Observable } from 'rxjs';
import { MultiSelectOption } from './models/multi-select-option.model';
import { MultiSelectOptionGroup } from './models/multi-select-option-group.model';
import * as i0 from "@angular/core";
/**
 * Type representing the multi-select component option input
 */
declare type MultiSelectOptionInput = Array<MultiSelectOption | MultiSelectOptionGroup>;
/**
 * Multi-select component
 */
export declare class MultiSelectComponent implements ControlValueAccessor {
    private renderer;
    private changeDetectorRef;
    /**
     * Set the value of the multi-select
     * @param value the value to set
     */
    set value(value: Array<string | number>);
    get value(): Array<string | number>;
    /**
     * The multi-select options/option groups
     */
    set options(options: MultiSelectOptionInput);
    /**
     * The amount of offset (in pixels) to place between the multi-select
     * and its list overlay
     * @private
     */
    private static readonly LIST_OFFSET;
    /**
     * List of arrow key keycodes
     * @private
     */
    private static readonly ARROW_KEYS;
    /**
     * ViewChild of the multi-select
     */
    multiSelect: ElementRef<HTMLDivElement>;
    /**
     * ViewChild of the multi-select button
     */
    multiSelectButton: ElementRef<HTMLButtonElement>;
    /**
     * ViewChild of the multi-select list
     */
    multiSelectList: ElementRef<HTMLDivElement>;
    /**
     * QueryList of multi-select option ViewChildren
     */
    multiSelectOptions: QueryList<ElementRef<HTMLButtonElement>>;
    /**
     * ContentChild of the multi-select option template
     */
    template: TemplateRef<HTMLElement>;
    /**
     * Whether or not the multi-select should be disabled
     */
    disabled: boolean;
    /**
     * Placeholder text to display when no option is selected
     */
    placeholder: string;
    /**
     * Aria label text
     */
    ariaLabel: string;
    /**
     * Class list to assign to the multi-select
     */
    classList: string;
    /**
     * Event emitted on value change, emits the new value
     */
    change: EventEmitter<(string | number)[]>;
    /**
     * BehaviorSubject tracking the input multi-select options/option groups
     */
    readonly _options: BehaviorSubject<MultiSelectOptionInput>;
    /**
     * BehaviorSubject tracking the current value of the multi-select
     */
    readonly _internalValue: BehaviorSubject<(string | number)[]>;
    /**
     * Observable map of option value (stringified if a number) to data context
     */
    readonly dataContextMap$: Observable<{
        [value: string]: {
            [key: string]: unknown;
        };
    }>;
    /**
     * Observable map of stringified option value to boolean indicating the user's selections
     */
    readonly selectionValueMap$: Observable<{
        [key: string]: boolean;
    }>;
    /**
     * The count of selected options as an Observable
     */
    readonly selectionCount$: Observable<number>;
    /**
     * Unique ID to assign to the multiSelect
     */
    readonly multiSelectId: any;
    /**
     * Whether or not to render the multi-select list
     */
    render: boolean;
    /**
     * Whether or not the multi-select is open
     */
    opened: boolean;
    /**
     * The index of the focused option in the multiSelect list
     */
    selectionIndex: number;
    /**
     * The current value of the multiSelect
     * @private
     */
    private _value;
    /**
     * Removes options that do not have both a label and a value,
     * also removes empty groups (or groups that have no valid options)
     * @param options the options to sanitize
     * @private
     */
    private static sanitizeOptionInput;
    /**
     * Add option label to data context if not present. If $implicit
     * value is not present, it will be added with the label as its value.
     * If $implicit is already present, it will add a label key to the context
     * @param label the option label
     * @param dataContext the option data context
     * @private
     */
    private static addLabelToDataContext;
    /**
     * Function to call on change
     */
    onChange: (value: any) => void;
    /**
     * Function to call on touch
     */
    onTouched: () => any;
    /**
     * Dependency injection site
     * @param renderer the Angular renderer
     * @param changeDetectorRef reference to the Angular change detector
     */
    constructor(renderer: Renderer2, changeDetectorRef: ChangeDetectorRef);
    /**
     * Write value
     * @param value the value to write
     */
    writeValue(value: Array<string | number>): void;
    /**
     * Register function on change
     * @param fn the function to register
     */
    registerOnChange(fn: any): void;
    /**
     * Register function on touch
     * @param fn the function to register
     */
    registerOnTouched(fn: any): void;
    /**
     * Set the disabled state
     * @param isDisabled disabled or not
     */
    setDisabledState?(isDisabled: boolean): void;
    /**
     * Reposition and resize the multiSelect on window resize
     */
    onWindowResize(): void;
    /**
     * Prevent default behavior for arrow key keydown event
     * @param event the keydown KeyboardEvent
     */
    onKeyDown(event: KeyboardEvent): void;
    /**
     * Close the multi-select list on tab and handle arrow key navigation
     * @param event the keyup KeyboardEvent
     */
    onKeyUp(event: KeyboardEvent): void;
    /**
     * Close the multi-select list (if opened) on click if outside the list
     * @param event the click MouseEvent
     */
    onClick(event: MouseEvent): void;
    /**
     * Close multi-select on escape keyup and focus on multi-select button
     * @param event the keyup KeyboardEvent
     */
    onEscapeKeyUp(event: Event): void;
    /**
     * Set focus to multi-select option on mouse enter and update selected index
     * @param option the multiSelect option to focus
     * @param index the index of the option to focus
     */
    onMultiSelectOptionMouseEnter(option: HTMLButtonElement, index: number): void;
    /**
     * Set focus to multi-select option on mouse move and update selected index
     * @param option the multiSelect option to focus
     * @param index the index of the option to focus
     */
    onMultiSelectOptionMouseMove(option: HTMLButtonElement, index: number): void;
    /**
     * Write value and close multi-select on option select
     * @param value the value to write
     * @param disabled whether or not the selected option is disabled
     */
    onMultiSelectOptionSelect(value: string | number, disabled: boolean): void;
    /**
     * Open the multi-select list and align it
     * @param event the click MouseEvent
     */
    openMultiSelect(event: MouseEvent): void;
    /**
     * Close the multiSelect list
     */
    closeMultiSelect(): void;
    /**
     * Position and resize the multi-select list on animation start if toState is open
     * @param event the Angular AnimationEvent
     */
    onAnimationStart(event: AnimationEvent): void;
    /**
     * Stop rendering the multi-select list on animation done if toState is close
     * @param event the Angular AnimationEvent
     */
    onAnimationDone(event: AnimationEvent): void;
    /**
     * If the input value is already in the value array, remove it. Otherwise add it
     * @param value the selected value
     * @private
     */
    private handleMultiSelectOptionSelect;
    /**
     * Align the multi-select list with the multiSelect
     * @private
     */
    private positionMultiSelectList;
    /**
     * Match the multi-select list width to the multi-select's width
     * @private
     */
    private resizeMultiSelectList;
    /**
     * Handle arrow keyup event
     * @param key the arrow key
     */
    private onArrowKeyUp;
    /**
     * Get the next enabled multi-select option (relative to the current selection index).
     * If the currently selected option is the final available option, it is
     * returned. If no selection has been made, the first available option is returned
     * @private
     */
    private getNextOption;
    /**
     * Get the previous enabled multi-select option (relative to the current selection index).
     * If the currently selected option is the first available option, it is
     * returned
     * @private
     */
    private getPreviousOption;
    static ɵfac: i0.ɵɵFactoryDeclaration<MultiSelectComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MultiSelectComponent, "wily-multi-select", never, { "value": "value"; "options": "options"; "disabled": "disabled"; "placeholder": "placeholder"; "ariaLabel": "ariaLabel"; "classList": "classList"; }, { "change": "change"; }, ["template"], ["template"]>;
}
export {};
