import { NgZone } from '@angular/core';
import { Observable, Subject, Subscription } from 'rxjs';
import { UserIdleConfig } from '../models/user-idle-config.model';
import * as i0 from "@angular/core";
/**
 * Service to track whether or not the current user is idle
 */
export declare class UserIdleService {
    private _ngZone;
    /**
     * Observable that emits based on the configured ping millisecond count
     */
    ping$: Observable<any>;
    /**
     * Events that can interrupts user's inactivity timer.
     */
    protected activityEvents$: Observable<any>;
    /**
     * Subject that tracks when the idle timer is running
     * @protected
     */
    protected _timerStart: Subject<boolean>;
    /**
     * Subject that tracks when the user has been determined to be idle
     * @protected
     */
    protected _idleDetected: Subject<boolean>;
    /**
     * Subject fired when the user has timed out
     * @protected
     */
    protected _timeout: Subject<boolean>;
    /**
     * Observable representing a merge of activity events (mouse move, window resize and keydown)
     * @protected
     */
    protected idle$: Observable<any>;
    /**
     * Observable representing a timer that fires every second until the configured count is met
     * @protected
     */
    protected timer$: Observable<any>;
    /**
     * Idle value in milliseconds.
     * Default equals to 10 minutes.
     */
    protected idleMillisec: number;
    /**
     * Idle buffer wait time milliseconds to collect user action
     * Default equals to 1 Sec.
     */
    protected idleSensitivityMillisec: number;
    /**
     * Timeout value in seconds.
     * Default equals to 5 minutes.
     */
    protected timeout: number;
    /**
     * Ping value in milliseconds.
     * Default equals to 2 minutes.
     */
    protected pingMillisec: number;
    /**
     * Timeout status.
     */
    protected isTimeout: boolean;
    /**
     * Timer of user's inactivity is in progress.
     */
    protected isInactivityTimer: boolean;
    /**
     * Boolean representing if the user is idle
     * @protected
     */
    protected isIdleDetected: boolean;
    /**
     * Subscription object to store the idle subscription
     * @protected
     */
    protected idleSubscription: Subscription;
    /**
     * Dependency injection site
     * @param config the optional config value
     * @param _ngZone the angular zone
     */
    constructor(config: UserIdleConfig, _ngZone: NgZone);
    /**
     * Start watching for user inactivity
     */
    startWatching(): void;
    /**
     * Stop the timer and unsubscribe from the idle subscription
     */
    stopWatching(): void;
    /**
     * Return observable for timer's countdown number that emits after idle.
     */
    onTimerStart(): Observable<number>;
    /**
     * Return observable for timeout is fired.
     */
    onTimeout(): Observable<boolean>;
    /**
     * Reset the timer
     */
    resetTimer(): void;
    /**
     * Set up the idle config
     * @param config the config to set
     * @private
     */
    private setConfig;
    /**
     * Stop the timer
     * @private
     */
    private stopTimer;
    /**
     * Setup timer.
     *
     * Counts every seconds and return n+1 and fire timeout for last count.
     * @param timeout Timeout in seconds.
     */
    protected setupTimer(timeout: number): void;
    /**
     * Setup ping.
     *
     * Pings every ping-seconds only if is not timeout.
     * @param pingMillisec
     */
    protected setupPing(pingMillisec: number): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UserIdleService, [{ optional: true; }, null]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<UserIdleService>;
}
