import { ChangeDetectorRef, EventEmitter } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { BehaviorSubject, Observable } from 'rxjs';
import { PopoverComponent } from '../popover/popover.component';
import * as i0 from "@angular/core";
/**
 * Interface representing a Date broken down by day/date/week/month/year
 * with extended metadata
 */
declare interface MetaDate {
    /**
     * The day of the week (starting at 0)
     */
    day: number;
    /**
     * The day of the month (starting at 1)
     */
    date: number;
    /**
     * The week of the year
     */
    week: number;
    /**
     * The month (starting at 0)
     */
    month: number;
    /**
     * The full year
     */
    year: number;
    /**
     * Whether or not the day is selectable
     */
    selectable: boolean;
}
/**
 * Interface representing a week of the year with metadata
 */
declare interface MetaWeek {
    /**
     * The week of the year (starting at 1)
     */
    week: number;
    /**
     * The year of the week
     */
    year: number;
    /**
     * Whether or not the week can be selected in the week picker
     */
    selectable: boolean;
    /**
     * The numeric dates of the days in the week
     */
    dates: Array<number>;
}
/**
 * Component to allow a user to select a week
 */
export declare class WeekPickerComponent implements ControlValueAccessor {
    private changeDetectorRef;
    /**
     * Set the value of the week picker
     * @param value the value to set
     */
    set value(value: {
        start: Date;
        end: Date;
    });
    /**
     * Set disabled
     */
    set disabled(disabled: boolean);
    /**
     * Set the valid date boundary for the week picker
     * @param dateRange
     */
    set dateRange(dateRange: {
        start?: Date;
        end?: Date;
    });
    /**
     * Class list to apply to the date range input
     */
    inputClassList: string;
    /**
     * Class list to apply to the week picker button
     */
    calendarButtonClassList: string;
    /**
     * The aria label to apply to the date range input
     */
    ariaLabel: string;
    /**
     * Format for the selected date range in the selection preview. Must
     * be a valid Angular DatePipe format
     */
    dateFormat: string;
    /**
     * Event emitted on week select
     */
    weekSelected: EventEmitter<{
        start: Date;
        end: Date;
    }>;
    /**
     * ViewChild of the calendar popover
     */
    calendarPopover: PopoverComponent;
    /**
     * The current date
     */
    readonly currentDate: MetaDate;
    /**
     * Array of days of the week
     */
    readonly weekDays: string[];
    /**
     * BehaviorSubject tracking the value of the week picker
     */
    readonly _internalValue: BehaviorSubject<{
        start: Date;
        end: Date;
    }>;
    /**
     * BehaviorSubject tracking the selectable date range
     */
    readonly _validSelectionInterval: BehaviorSubject<{
        start: Date;
        end: Date;
    }>;
    /**
     * BehaviorSubject tracking the currently selected month
     */
    readonly _selectedMonth: BehaviorSubject<number>;
    /**
     * BehaviorSubject tracking the currently selected year
     */
    readonly _selectedYear: BehaviorSubject<number>;
    /**
     * The selected week of the year of the start of the selection as an Observable
     */
    readonly selectedWeek$: Observable<number>;
    /**
     * The year of the start of the selected week as an Observable
     */
    readonly selectedYear$: Observable<number>;
    /**
     * Observable boolean representing if next week (relative to the current selection) is selectable
     */
    readonly canSelectNextWeek$: Observable<boolean>;
    /**
     * Observable boolean representing if last week (relative to the current selection) is selectable
     */
    readonly canSelectLastWeek$: Observable<boolean>;
    /**
     * The range of selectable years as an Observable
     */
    readonly validYearRange$: Observable<Array<number>>;
    /**
     * An array of MetaWeeks representing a month as an Observable
     */
    readonly fullMonth$: Observable<Array<MetaWeek>>;
    /**
     * The value of the week picker
     * @private
     */
    private _value;
    /**
     * Whether or not the control is disabled
     * @private
     */
    private _disabled;
    /**
     * Generate an Array of numbers representing the span of years between the input
     * @param minYear the start of the range
     * @param maxYear the end of the range
     * @param currentYear the current year
     */
    private static generateYearRange;
    /**
     * Generate a month with week and selectable status metadata
     * @param month the month to generate
     * @param year the year of the month to generate
     * @param selectionInterval the interval representing the
     *                              minimum to the maximum week of the year
     * @private
     */
    private static generateMonth;
    /**
     * Get the input date as a MetaDate
     * @param date the date to transform
     * @param selectable whether or not the date is selectable
     * @private
     */
    private static getMetaDate;
    /**
     * Function to call on change
     */
    onChange: (value: any) => void;
    /**
     * Function to call on touch
     */
    onTouched: () => any;
    /**
     * Dependency injection site
     * @param changeDetectorRef the Angular ChangeDetectorRef
     */
    constructor(changeDetectorRef: ChangeDetectorRef);
    /**
     * Get the value of the week picker
     */
    get value(): {
        start: Date;
        end: Date;
    };
    /**
     * Get whether or not the control is disabled
     */
    get disabled(): boolean;
    /**
     * Write value
     * @param value the value to write
     */
    writeValue(value: {
        start: Date;
        end: Date;
    }): void;
    /**
     * Register function on change
     * @param fn the function to change
     */
    registerOnChange(fn: any): void;
    /**
     * Register function on touch
     * @param fn the function to register
     */
    registerOnTouched(fn: any): void;
    /**
     * Set disabled state
     * @param isDisabled whether or not the control is disabled
     */
    setDisabledState(isDisabled: boolean): void;
    /**
     * Open the week picker popover
     * @param event the event to pass to the popover
     */
    openCalendar(event: Event): void;
    /**
     * Handle week select
     * @param week the week of the year
     * @param selectable whether or not the week is selectable
     */
    onWeekSelect(week: number, selectable: boolean): void;
    /**
     * Select next week (relative to the week of the current selection)
     */
    selectNextWeek(): void;
    /**
     * Select last week (relative to the week of the current selection)
     */
    selectLastWeek(): void;
    /**
     * Select the current week
     */
    selectCurrentWeek(): void;
    /**
     * Update model
     * @param value the new value of the model
     * @private
     */
    private updateModel;
    /**
     * Set the selection interval
     * @param interval the input selection interval
     * @private
     */
    private setSelectionInterval;
    /**
     * Set the selectable status of the current date
     * @private
     */
    private setCurrentDateSelectable;
    static ɵfac: i0.ɵɵFactoryDeclaration<WeekPickerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<WeekPickerComponent, "wily-week-picker", never, { "value": "value"; "disabled": "disabled"; "dateRange": "dateRange"; "inputClassList": "inputClassList"; "calendarButtonClassList": "calendarButtonClassList"; "ariaLabel": "ariaLabel"; "dateFormat": "dateFormat"; }, { "weekSelected": "weekSelected"; }, never, never>;
}
export {};
