import { HttpClient, HttpErrorResponse, HttpParams } from '@angular/common/http';
import { Observable } from 'rxjs';
/**
 * This class provides some foundational REST endpoint call capabilities. It will do things like unpack lists into native objects and
 * return Observables so that you don't have to deal with mapping each and every response. It'll also log errors to the console and pass
 * along the error text for you.
 */
export declare class BaseDataService {
    protected http: HttpClient;
    /**
     * Extensions of this class can provide the Base URL so that they don't need to write out the full URL for every call made.
     */
    protected getBaseUrl(): string;
    /**
     * Takes an HTTPClient object so that it can make REST calls.
     *
     * @param http
     */
    constructor(http: HttpClient);
    /**
     * Gets a result from an endpoint. Executes an HTTP GET.
     *
     * @param url
     * @param params
     */
    handleGet(url: string, params?: HttpParams): Observable<any>;
    /**
     * Will get a single result from an endpoint. Executes an HTTP GET.
     *
     * @param url
     */
    handleGetOne(url: string): Observable<any>;
    /**
     * Gets a List of Values. Will unpack the data object automatically. Executes an HTTP GET.
     *
     * @param url
     */
    handleGetList(url: string): Observable<any>;
    /**
     * Gets a file from an ednpoint. Executes an HTTP GET.
     *
     * @param url
     * @param params
     */
    handleFileGet(url: string, params?: HttpParams): Observable<any>;
    /**
     * The handleFileGet will use this to get a file.
     *
     * @param url
     * @param isFileResponse
     * @param params
     */
    private handleGetDetailed;
    /**
     * Posts data to an endpoint. HTTP POST.
     *
     * @param url
     * @param payload
     */
    handlePost(url: string, payload: any): Observable<any>;
    /**
     * Posts data to an endpoint with an expected return of a File.
     *
     * @param url
     * @param payload
     */
    handlePostWithFileResponse(url: string, payload: any): Observable<any>;
    /**
     * The handlePost methods will use this to make Post calls easier.
     *
     * @param url
     * @param payload
     * @param isJson
     * @param isFileResponse
     */
    private handlePostDetailed;
    /**
     * Update data with a REST call. HTTP PUT.
     *
     * @param url
     * @param payload
     */
    handlePut(url: string, payload: any): Observable<any>;
    /**
     * Used by the handlePut method to make it simpler and the guts more reusable.
     *
     * @param url
     * @param payload
     * @param isJson
     */
    private handlePutDetailed;
    /**
     * Executes an HTTP DELETE to remove data.
     *
     * @param url
     */
    handleDelete(url: string): Observable<any>;
    /**
     * Handles an Observable error
     *
     * @param error
     */
    handleObservableError(error: HttpErrorResponse): Observable<any>;
    /**
     * Logs an error and rethrows it
     *
     * @param error
     */
    handleError(error: HttpErrorResponse): Observable<any>;
    /**
     * Performs a deep copy of a JS object.
     *
     * @param o
     */
    deepCopy<T>(o: T): T;
    /**
     * Gets the expected response type from an endpoint
     *
     * @param isFileResponse
     */
    private getOptions;
}
